import { env as getEnv } from './get-system-info';
import { isObject, isString, compareVersion } from '@jolibox/common';
import { getCanIUseConfig, get } from '../utils/can-i-use';

const __VERSION__ = '__JOLIBOX_LOCAL_SDK_VERSION__'; // mock

export function canIUse(schema: string): boolean {
  const env = getEnv();
  const platform = env.data?.deviceInfo?.platform;
  if (!platform) {
    return false;
  }

  const [name, ...rest] = schema.split(':');

  const api = getCanIUseConfig(platform == 'h5' ? platform : 'native', name);

  if (!api) return false;

  const apiVersion = api['version'];

  if (typeof apiVersion !== 'string') return false;

  if (compareVersion(__VERSION__, apiVersion, '<')) return false;

  if (rest.length === 0) return true;

  return checkRest(api, rest) || checkRest(api['properties'], rest);
}

function checkRest(info: unknown, paths: string[]) {
  if (!info) return false;
  const v = get(info as Record<string, unknown>, paths);
  if (!v) return false;
  if (isObject(v)) return true;
  if (isString(v)) return compareVersion(__VERSION__, v, '>=');
  return false;
}
